Datepicker Visual Test : Datepicker ticket #4071

# #4071 - 'length' is null or not an object

## Summary

In Internet Explorer, when a event such as click on one element causes a change event on another element to trigger programmatically, any change event handler that was bound to that second element through onchange gets the click event instead of the change event.

## Steps to reproduce

To demonstrate the issue, do one of the following:

- Click the input to open the Datepicker, then select a date
- Or press a number in the text field and blur
- Or click a button below

Each will trigger change on the text input. The input has a handler bound in three different ways. Notice the difference when pressing a number in the input and bluring versus either selecting a date or pressing one of the first three buttons. In Internet Explorer, when the issue is present, 2 out of the three event objects are of type 'click' instead of 'change' and have the wrong corresponding srcElement/target when the datepicker or one of the first three buttons are clicked.